WheelWidgetState class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAnimationRunning → bool
-
final
- isDialogOpen → bool
-
final
- isResetLoading → bool
-
final
- previousLastResultId → String?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showConfig → bool
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{bool? showConfig, bool? isDialogOpen, bool? isAnimationRunning, bool? isResetLoading, String? previousLastResultId}) → WheelWidgetState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited